Krackhardt Friendship Network Perception Errors
Source:R/data.R
krackhardt_friendship_perceptions.RdIndividual perceptions of the Krackhardt friendship network containing systematic perception errors and biases.
R/data.R
krackhardt_friendship_perceptions.RdIndividual perceptions of the Krackhardt friendship network containing systematic perception errors and biases.