Skip to contents

Computes census of imaginary errors

Usage

count_imaginary_census(x, counter_type = 0L)

Arguments

x

An object of class barry_graph.

counter_type

An integer indicating the type of census to compute (see details).

Value

A data frame of class "imaginary_census" with columns id, name, and value.

Details

We can also separate the counts as a function of whether the perceiver is looking into all ties, only ties including them, or only ties not including them. This is controlled by the counter_type argument:

  • 0: All ties

  • 1: Only ties including the perceiver

  • 2: Only ties not including the perceiver

There are ten (10) values:

  • (01) Accurate null

  • (02) Partial false positive (null)

  • (03) Complete false positive (null)

  • (04) Partial false negative (assym)

  • (05) Accurate assym

  • (06) Mixed assym

  • (07) Partial false positive (assym)

  • (08) Complete false negative (full)

  • (09) Partial false negative (full)

  • (10) Accurate full

Examples

data(krackhardt_advice)
data(krackhardt_advice_perceptions)

n_people <- 21
advice_matrix <- matrix(0L, nrow = n_people, ncol = n_people)
advice_matrix[cbind(krackhardt_advice$from, krackhardt_advice$to)] <-
  krackhardt_advice$value

krack_graph <- new_barry_graph(
  c(list(advice_matrix), krackhardt_advice_perceptions)
)
census <- count_imaginary_census(krack_graph)
head(census)
#>   id                   name value
#> 1  0 (01) Accurate null (0)    45
#> 2  1 (01) Accurate null (1)    53
#> 3  2 (01) Accurate null (2)    53
#> 4  3 (01) Accurate null (3)    49
#> 5  4 (01) Accurate null (4)    47
#> 6  5 (01) Accurate null (5)    43
summary(census)
#>                 Accurate assym                   Accurate null  
#>                            1052                             992 
#>                  Accurate full  Partial false negative (assym)  
#>                             469                             463 
#> Partial false positive (assym)   Partial false negative (full)  
#>                             412                             395 
#>  Partial false positive (null)                     Mixed assym  
#>                             343                             173 
#> Complete false negative (full)  Complete false positive (null)  
#>                              81                              30